package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````?!\```````!``````````,BA````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````&^@`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````-)0`````
M```TE``````````0`````````0````8```"@FP```````*"K````````H*L`
M``````"P!````````-@$`````````!`````````"````!@```+B;````````
MN*L```````"XJP```````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```#XC````````/B,````````^(P```````#D````````
M`.0`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````H)L```````"@
MJP```````*"K````````8`0```````!@!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`"N&P$A.QD]8A*O/7ZROO0-),OO9!````!`````!````1TY5```````$````
M#P`````````1````1@````0````(````()`0`05`!,0H`@$$@(8$A(*)``()
M(`0(B(`00;H``H@`````1@```$D```!,````30```%4```!6````6````%H`
M``!;````7````%X```!@````80```&,``````````````&[%WQ_.WD<M:W^:
M?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@
MF4_#FVL)0]9FK\QF&7X*AT)%U>R)!W#3<U"?V#-BV^T^S])L%8PES`PZEPO_
M8?)A?ZF<F^"G`@IK&IY0H^#[20``````````````````````````````````
M`````````P`,`/`=``````````````````#4`@``$0``````````````````
M``````#5````$@````````````````````````#-`0``$@``````````````
M``````````"P`@``$@````````````````````````"'````$@``````````
M``````````````!.`0``$@````````````````````````"#`@``$@``````
M``````````````````#4`0``$@````````````````````````!E`0``$@``
M``````````````````````"5`0``$@````````````````````````#K````
M$@````````````````````````"?`@``$@````````````````````````"Z
M`@``$0````````````````````````"*`@``$@``````````````````````
M``"(`0``$@`````````````````````````<`0``$@``````````````````
M```````,`0``$@````````````````````````#^````$@``````````````
M``````````#L`0``$@````````````````````````#;`0``$@``````````
M``````````````"^`0``$@````````````````````````#"`@``$@``````
M```````````````````!````(``````````````````````````"`@``$@``
M``````````````````````!L`0``$@`````````````````````````=````
M(``````````````````````````P`@``$@````````````````````````"F
M`0``$@`````````````````````````W````$@``````````````````````
M``"1`@``$@````````````````````````"X`@``$0``````````````````
M``````!4````%@````````````````````````#[`0``$@``````````````
M```````````^`0``$@````````````````````````"8`@``$@``````````
M``````````````!G````$@````````````````````````!M`@``$@``````
M``````````````````#$````$@````````````````````````!X````$@``
M``````````````````````"-`0``$@````````````````````````"H````
M$@````````````````````````#:````$@````````````````````````#%
M`0``$@````````````````````````!F`@``$@``````````````````````
M``#F`0``$@`````````````````````````P`0``$@``````````````````
M``````"?`0``$@````````````````````````!0`@``$@``````````````
M``````````!)`@``$0````````````````````````#?````$@``````````
M``````````````"V`0``$@`````````````````````````O`@``$@``````
M``````````````````!7`@``(@````````````````````````"3````$@``
M```````````````````````+`@``$@````````````````````````#A`0``
M$@````````````````````````!T`@``$@````````````````````````!9
M`0``$@`````````````````````````A`@``$@``````````````````````
M``"<`P``$@````````````````````````"W````$0``````````````````
M```````3`@``$@`````````````````````````E`0``$@``````````````
M``````````!%````$@`````````````````````````W`@``$@``````````
M``````````````![`@``$@````````````````````````!W`0``$@``````
M``````````````````"O`0``$@````````````````````````"E`P``$@`,
M`((U````````I``````````W!```$@`,`/8N````````W`0```````!$`@``
M$@`,`/`=````````B@$````````<`P``$@`,`!0F`````````@`````````Z
M`P``$@`,`-(S````````L`$```````!=!```$@`,`!8F````````U@$`````
M```=!```$``6`%"P```````````````````M`P``$@`,`.PG````````(@``
M``````!0`P``$@`,`&@L````````3@````````"]`P``$0`-`(!+````````
M!`````````#Z`P``$@`,`.1(````````W``````````5!```$@`,`"XE````
M````*``````````R!```$``6`'BP``````````````````!+!```$@`,`#8N
M````````P`````````!T!```$@`,`+8L````````1`````````#,`P``$``5
M``"P``````````````````!T`P``$@`,``XH`````````@$```````#H`P``
M$`#Q_P"X``````````````````!$!```$``5`%"P``````````````````!J
M!```$0`5`$BP````````"``````````%!```$``5`%"P````````````````
M``#2`P``$@`,`'P?````````(@````````#9`P``$``5``"P````````````
M```````I!```$@`,`)!(````````5`````````#.`P``(``5``"P````````
M``````````"Q`P``$``6`'BP``````````````````"*`P``$@`,`!XN````
M````&`````````!>`P``$@`,`%8E````````O@````````"``P``$@`,`,!)
M````````L@$```````!\!```$@`,`!`I````````6`,`````````7TE435]D
M97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B
M;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O
M;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E
M=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D
M;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S
M970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]A;&QO8P!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D9&ER
M-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!M96UM
M;W9E`'-T<G1O:P!S=')L96X`<FUD:7(`<F5A9`!M:V1I<@!?7W9F<')I;G1F
M7V-H:P!G971P:60`<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?
M9G!R:6YT9E]C:&L`;'-T870V-`!?7VQI8F-?<W1A<G1?;6%I;@!S=&1E<G(`
M;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!M96UC;7``;65M<V5T`&]P
M96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R;F]?;&]C
M871I;VX`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S
M=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C,X`&QI8F,N<V\N-@!L9"UL
M:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?
M8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?7T)34U]%
M3D1?7P!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`7U]$051!7T)%1TE.
M7U\`7U]G;&]B86Q?<&]I;G1E<B0`<VAA7W5P9&%T90!?7U-$051!7T)%1TE.
M7U\`>'-?:6YI=`!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M
M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY
M7W!A<E]P;`!P87)?9&EE`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,T`$=,24)#
M7S(N,S,`1TQ)0D-?,BXR-P```````@`!``,``P`!``$``P`#``,``P`!``,`
M`P`#``,``0`!``$``P`#``,``P`!``,``0`!``0``P`!``,``P`!``,``0`#
M``$``P`!``$``P`!``,``P`#``,``0`#``,``P`!``,`!``#``$``P`#``,`
M`0`#``,``0`#``$``0`%``,``P`#``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``````````$`
M`P#V`@``$````$````"TD98&```%`(D$```0````LY&6!@``!`"4!```$```
M`(>1E@8```,`GP0````````!``$```,``!``````````AY&6!@```@"?!```
M`````*"K`````````P````````">'P```````*BK`````````P`````````R
M(````````+"K`````````P````````#X'P```````/BO`````````P``````
M``#P'0````````"P`````````P``````````L````````!BP`````````P``
M``````#@3````````""P`````````P````````!(3P```````"BP````````
M`P````````!03P```````#"P`````````P````````!83P```````#BP````
M`````P````````!@3P```````$BP`````````P````````!H3P```````*"O
M`````````@````(``````````````*BO`````````@````P`````````````
M`+"O`````````@````X``````````````+BO`````````@```!@`````````
M`````,"O`````````@```!L``````````````,BO````````"P```"$`````
M`````````-"O`````````@```",``````````````-BO`````````@```"4`
M`````````````."O`````````@```#(``````````````.BO`````````@``
M`#8``````````````/"O`````````@```#X``````````````-BM````````
M!0````,``````````````."M````````!0````0``````````````.BM````
M````!0````4``````````````/"M````````!0````8``````````````/BM
M````````!0````<```````````````"N````````!0````@`````````````
M``BN````````!0````D``````````````!"N````````!0````H`````````
M`````!BN````````!0````L``````````````""N````````!0````T`````
M`````````"BN````````!0````\``````````````#"N````````!0```!``
M`````````````#BN````````!0```!$``````````````$"N````````!0``
M`!(``````````````$BN````````!0```!,``````````````%"N````````
M!0```!0``````````````%BN````````!0```!4``````````````&"N````
M````!0```!8``````````````&BN````````!0```!<``````````````'"N
M````````!0```!D``````````````'BN````````!0```!H`````````````
M`("N````````!0```!P``````````````(BN````````!0```!T`````````
M`````)"N````````!0```!X``````````````)BN````````!0```!\`````
M`````````*"N````````!0```"(``````````````*BN````````!0```"0`
M`````````````+"N````````!0```"8``````````````+BN````````!0``
M`"<``````````````,"N````````!0```"@``````````````,BN````````
M!0```"D``````````````-"N````````!0```"H``````````````-BN````
M````!0```"L``````````````."N````````!0```"P``````````````.BN
M````````!0```"T``````````````/"N````````!0```"X`````````````
M`/BN````````!0```"\```````````````"O````````!0```#``````````
M``````BO````````!0```#$``````````````!"O````````!0```#,`````
M`````````!BO````````!0```#0``````````````""O````````!0```#4`
M`````````````"BO````````!0```#<``````````````#"O````````!0``
M`#@``````````````#BO````````!0```#D``````````````$"O````````
M!0```#H``````````````$BO````````!0```#L``````````````%"O````
M````!0```#P``````````````%BO````````!0```#T``````````````&"O
M````````!0```#\``````````````&BO````````!0```$``````````````
M`'"O````````!0```$$``````````````'BO````````!0```$(`````````
M`````("O````````!0```$,``````````````(BO````````!0```$0`````
M`````````)"O````````!0```$4``````````````)>3```S`\-!`[Z#-Q,#
M0_V3@H,W$U,3`(.R@@!G``X`%YX```,^CC9G`PX`$P```!>>```#/@XV9P,.
M`!,````7G@```SZ.-6<##@`3````%YX```,^#C5G`PX`$P```!>>```#/HXT
M9P,.`!,````7G@```SX.-&<##@`3````%YX```,^CC-G`PX`$P```!>>```#
M/@XS9P,.`!,````7G@```SZ.,F<##@`3````%YX```,^#C)G`PX`$P```!>>
M```#/HXQ9P,.`!,````7G@```SX.,6<##@`3````%YX```,^CC!G`PX`$P``
M`!>>```#/@XP9P,.`!,````7G@```SZ.+V<##@`3````%YX```,^#B]G`PX`
M$P```!>>```#/HXN9P,.`!,````7G@```SX.+F<##@`3````%YX```,^CBUG
M`PX`$P```!>>```#/@XM9P,.`!,````7G@```SZ.+&<##@`3````%YX```,^
M#BQG`PX`$P```!>>```#/HXK9P,.`!,````7G@```SX.*V<##@`3````%YX`
M``,^CBIG`PX`$P```!>>```#/@XJ9P,.`!,````7G@```SZ.*6<##@`3````
M%YX```,^#BEG`PX`$P```!>>```#/HXH9P,.`!,````7G@```SX.*&<##@`3
M````%YX```,^CB=G`PX`$P```!>>```#/@XG9P,.`!,````7G@```SZ.)F<#
M#@`3````%YX```,^#B9G`PX`$P```!>>```#/HXE9P,.`!,````7G@```SX.
M)6<##@`3````%YX```,^CB1G`PX`$P```!>>```#/@XD9P,.`!,````7G@``
M`SZ.(V<##@`3````%YX```,^#B-G`PX`$P```!>>```#/HXB9P,.`!,````7
MG@```SX.(F<##@`3````%YX```,^CB%G`PX`$P```!>>```#/@XA9P,.`!,`
M```7G@```SZ.(&<##@`3````%YX```,^#B!G`PX`$P```!>>```#/HX?9P,.
M`!,````7G@```SX.'V<##@`3````%YX```,^CAYG`PX`$P```!>>```#/@X>
M9P,.`!,````7G@```SZ.'6<##@`3````%YX```,^#AUG`PX`$P```!>>```#
M/HX<9P,.`!,````7G@```SX.'&<##@`3````%YX```,^CAMG`PX`$P```!>>
M```#/@X;9P,.`!,````=<8;LIN2JAZ+HRN!._)>4``"#M"0:+N@RY`P(,`!H
M"#[.G&`^](%'[_"?^!>6```#-L88LH47E0```S4E&^\@4%27EP``@[?G&X/'
M!P#QSY>7``"#MX<8%Y0``!,$!"&2EYAC<DF#1Z=+&P5)``X%D^<W`",-]TKO
M\)_NPF7R1PCDF&$-*:J&&.$7-P``$P?G"QCE%Y<```,W1QP8Z1<W```3!R<+
M&.T%1V-9]PP;B#<`0H:A!1%'B&&3%S<`MI<%)XCCH07C&0?_FP<&`(X'"&RV
MEP%'2H:7!0``DX7%8".P!P#O\-^]/<4(;),)00+O\!_=*HG.A1<U```3!878
M[P!`%"G-"&SO\)^W[_!?SB)WG&"YCP%'O>?F8$9DIF3B>4J%!FDE88*`[_!_
MR1>4```3!*03".PAQ>_P?]&7EP``@[>G"85F,X='`!AC-I<C!P>:,;<(;._P
MG[YYMPAH`<7O$`!C1;?.A1<U```3!>7)[P`@#0CH6=7EMY%'@;\%1>_P_[KO
M\+_E``#O`"`"JH<7E0```S5E!X)E,``3<0'_@48!1PJ([_"?X0*0EZ$``).!
M(8:"@```%Y4``!,%90J7EP``DX?G"6.(IP"7EP``@[>G_Y'#@H>"@!>5```3
M!44(EY4``).%Q0>)C9/7-4#]D;Z5A869Q9>7``"#MV?]D<."AX*`01$BX!>4
M```3!$0%@T<$``;DA>.7EP``@[?'_9''%Y4```,UI?Z"E^_PO_B%1R,`]`"B
M8`)D00&"@&F_.7$&_"+X6<5:X)>7``"#MR?W`[L'`&,!"PA*\$[L4NB#1P4`
MJHDNBBJ)$P?0`Z7+8X;G`(-'&0`%"?W[.PDY00,T"P`YS";T5N3:A),*T`-*
MALZ%(H7O\'^@LP<D`0GE@\<'`&.`5P.`9*$$=?"B=`)YXFE":J)J`FOB<"*%
M0G0A88*`LX1D08V$!0DC()H`2I3QOP%$U;<":P%$^;\!246W`GGB:4)J`FO!
MOW%Q(O$F[0;UEY0``(.TA.LL`)Q@/N6!1RJ$[_!_P`WAXD>]9A%G]8]CA><`
M*6=CFN<`B44BA>_POY\3-14`$:`!12IGG&"YCP%'D>>J<`ITZF1-88*`[_"_
MR3%Q3NT&_9>9``"#N0GF@[<)`#[E@4<9Q2+Y@T<%`"J$B>]*="IG@[<)`+F/
M`4=CE@<,ZG#J:2EA@H`F]4KQ[_"?Q*J$4<DFA>_P_Y9!P8-&-0$3"34!FX8F
M_8'F@T89`/W2`T<U`1L')_T]RR*%4NGO\'^2*HI*A>_P_Y$[!:H`"27O\%^2
MRH<BAY<V``"3AD:<?5:%12J)[_#_NBP`2H7O\'^>_5=C"/4`XD>]9A%G]8]C
M@.<$2H7O\/^82H7O\)^G)H5*:N_P'X]1\2:%[_"?G"*%[_`_EDITJG0*>9FW
M`T<9`!L')_U1\P-'*0`AW[6_2H7O\-_PT;<B^2;U2O%2Z>_P7[D=<:+HIN3*
MX%+XANQ._%;T6O"#QP4`%YD```,YJ=2JA).'-_R3MQ<`,X3U`"*%@S<)`#[D
M@4?O\+^%*HI,`":%[_!?VWG)JHGO\)^$8W9%"Y)*%YL```,[Z]&."@/'!`"F
MAY,&T`-C"`<28P;7``/'%P"%!WW[A9^#.0L`$P4J`#Z5UIGO\-^!(["I`#'%
M`S<+`(/'!``3A10`5I<48Q,&T`,C@/8`@>N]H(-'!0`%!:,`]P"MPS:'A0;C
MF,?^DP;0`Y,'%P`C`-<``T<$`(4'!02CC^?^=?LB9X,W"0"YCP%'W>_F8$9D
MIF0&:>)Y0GJB>@)[)6&"@(-'!`"%"04$HX_Y_O';@T<$`(4)!02CC_G^_?/1
MMS:'7;=>[&+H%YL```,[*\4#/`L`@S<,`+7'XH>!29AGSH:A!X4I9?^-)I.5
M-@"7EP``DX='S9A#%>L%1RZ%F,/O\*_TJHLQQ9.:.0!6AN*%[_"_C2,P>P&;
MAQD`C@>^FR.P"P#B:T)L3L+QO6*%[_#?E2,PJP"JBPG-DYHY`.F_@4?%M<%%
M@4E=MU[L8NCO\-^>XFM";#6W77%6[/UWA6K]<N$7$X<*`:+@)OQ*^$[T4O"&
MY#Z7%I&NB;,%)P`3AXH`"I<%9!>9```#.4FX*HH3!O3_%R4``!,%97:#-PD`
M'..!1^_P;_:;!`4`8UZ0`!.'"@$*ES,$AT";A_3_/I0#1X3_*>.=[Y>7``"#
MMZ>V3H;2A9*7B&/O\"_NA6>A!XJ7F&.#-PD`N8\!1[GGA6(6D:9@!F3B=$)Y
MHGD">N)J86&"@+Z$_7<%9^$700<^ES,$)P`FAI,%\`(BA>_P_X%%U9>7``"#
MMP>QIH8BAI*7B&/2A>_P;_E5M^_P'Y!!$2+@%Y0```,T!*\&Y)=F``"3AF9_
MLP=$`(AC%Y8```,V!JZ7)0``DX6%:N_P'XD2E`A@`F2B8!<W```3!T>B@4>Z
MAA<6```3!J;KER4``).%!6I!`6_P;_"7EP``@[>GJ9=F``"3AB9Z%Y8```,V
M)JF2EXACER4``).%965O\/^#77$F_/ERB62&Y*+@2OA.]!.'A`$6D0J7EYD`
M`(.Y*:.#MPD`'..!1^_P+^CY=Z$7DX8$`KZ6,X0F``5F*H>7)P``DX='9)<F
M``"3AD9D!0:%12*%[_!O_?UUP163AP0"KI>SA"<`(H4%9J:%[_#OW1L$!0`!
M26-/!``;!10`[_#/T"J)`<DBAJ:%2I3O\._@(P`$`(EGX0>*EYAC@[<)`+F/
M`4>9ZXEB%I&F8$J%!F3B=$)YHGEA88*`[_`/_(FWA6;]=U%Q_7*3AT?W$X<&
M":+QINW*Z6+QAO7.Y=+A5OU:^5[U9NUJZ3Z7%I$NA+,%)P`3AX8("I<7G```
M`SPLE2J)@S<,`!SC@4<7)0``$P6%6>_PWYRJA),%\`)*A>_PS^$AQ1<E```3
M!>58RH7O\-^[2H6%9Y.'APB*EYAC@S<,`+F/`4=CE@<4A6(6D:YP#G3N9$YI
MKFD.:NIZ2GNJ>PI\ZFQ*;6UA@H`BA>_P[]^7)0``DX4E5>_P+[LJA%W1A6?]
M>>$9$X<'"4Z7LPDG`!.'!PF3AP<)BI>%:GUZLXQ708-'!``3"HKW4I>7*P``
MDXOK41<K```3"^M1,PHG`,G+D<2BA2:%[_`OSS7%(H7O\*^ZDP?U_Z*7*HV3
M!O`"8VCT`#&H(X`'`/T78P;T``/'!P#C"=?^(H7O\`^X*HU*A>_PC[=JE04%
MXWU5\85%2HC>AR*'VH8%9DZ%[_#OX-*%3H7O\&_$`>F#IXSXO68A9_6/8X_G
M`I<E``"3A:5(`47O\(^N*H3C#@7L@T<$`*W[D<2#QP0`FX<G_9G'!4T7)```
M$P2D0V&_@\<4`.G7_;>%14Z%[_!/M%W]SH47)0``$P5%0^_P7Z9.A>_P[\U5
MM>_PC]Y!$9,%\`(BX`;D*H3O\(_/&<$3!!4`(H4"9*)@00%O\&_+>7&%9_UR
M2N@&]"+P)NP3AX<`%I$7B0```SGI=PJ7@S<)`!SC@4=-P8-'!0"JA,G/[_`O
MJ1,&%0"%9RJ$8^_'"GUW81?!![J7,X<G`*:%.H7O\"^YDP?T_ZJ7DP;P`F-H
M]0`1J".`!P#]%V.&IP`#QP<`XPG7_GUUA6=A%<$'JI<SA"<`DP7P`B*%[_"/
MQ0W-8V*D!GUUA6=A%<$'JI<SA2<`[_`/P85GH0>*EYAC@S<)`+F/`4>AYX5B
M%I&B<`)TXF1":45A@H"%9Z$'BI>88X,W"0"YCP%'G>.%8A:1HG`"=.)D0FD7
M)0``$P7%+T5A;_`OO",`!0!QOP%%;;?O\$_,.7$B^";T2O!.[`;\EX0``(.T
M1&B<8#[D@4=``!<I```3"4DPEXD``(.YR6>BA4J%[_!/[Q7!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_P+^UE\1<I```3"8DMEXD``(.Y"62BA4J%
M[_"/ZQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P;^EE\1<I```3
M"4DJEXD``(.Y26"BA4J%[_#/YQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_PK^5E\1<I```3"8DGEXD``(.YB5RBA4J%[_`/Y!7!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_P[^%E\1<I```3"4DDEXD``(.YR5BBA4J%
M[_!/X!7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P+]YE\1<I```3
M"8DAEXD``(.Y"56BA4J%[_"/W!7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_P;]IE\1<I```3"4D6EXD``(.Y25&BA4J%[_#/V!7!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_PK]9E\1<I```3"0D;EXD``(.YB4VBA4J%
M[_`/U17!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P[])E\1<I```3
M"4D8EXD``(.YR4FBA4J%[_!/T17!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_P+\]E\1<I```3"8D5EXD``(.Y"4:BA4J%[_"/S17!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_P;\ME\1<I```3"4D(EXD``(.Y24*BA4J%
M[_#/R17!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PK\=E\:*%%R4`
M`!,%Y0[O\*_&JH49Q1<E```3!>4+[_!OYJ*%%R4``!,%A0[O\,_$JH49Q1<E
M```3!04/[_"/Y**%%R4``!,%)0_O\._"JH4%S1<E```3!:7^[_"OXB)GG&"Y
MCP%'J>-"=.)PHG0">>)IER4``).%I0X7)0``$P6E`B%A;_`/X**%%R4``!,%
MI0OO\&^^JH5YT1<E```3!:4"[_`OWF6_[_#/E@$1(N@&[!>$```#-"0S3``7
M)0``$P6%`!Q@/N2!1^_P[[H5P8-'!0`!18G'DX<'_3,U\``B9QQ@N8\!1YGG
MXF!"9`5A@H`!1?6W[_#OD1UQ!NPJCA>%```#-44R"&$3`X$"+O0R^#;\ON2Z
MX,+HQNR7AP``@[>'+)J&<H:%19AC.N0!1QK@[^`_YQ,%\`_OX+_B67&B\,%R
M063.Y-+@9NR&]*;LRNA6_%KX7O1B\!,'A``6D0J7EXP``(.\+"B#MPP`'..!
M1PE&@44JBN_@W_&3"?7_$]?Y0T&3LX?I`,(7P9.9C[.)^4!CQPD*P73!%),'
M!`'!:Z:7_5JSA"<`H0L=3!>)```3">DI07L!1LZ%4H7OX'_M8PA5"5Z&IH52
MA>_@G_H!)6,*50=C<ZP&814SA*0`8W:4`*&H?11C:I0$(4;*A2*%[^`_YV7Y
MP7=!9\$700<^E[,')P`S!?1`3I7!9Z$'BI>88X.W#`"YCP%'J>/!8A:1IG`&
M=.9D1FFF:09JXGI">Z)[`GSB;&5A@H#:F>.=:?=]5>&W%R4``!,%Y?+O\-_J
M%R4``!,%)?'O\!_J[^!_^T$1!N3OX/_)`27OX)_T$<$(8:)@00&"@#EQ)O1*
M\`;\%XD```,Y*1:JA$P`%R4``!,%9>^#-PD`/N2!1^_PKYT9Q2+X@T<%`"J$
MG>-"=")G@S<)`+F/`4>FA1<E```3!87LK>?B<*)T`GDA86_P;[LFA4[L[^#_
MPZJ)(H7OX'_#3I4)!>_@_\,BB)<G``"3AP?7)H>7)@``DX9FUWU6A44JA._@
M'^PB9X,W"0"YCP%'E>.BA4)TXFGB<*)T`GD7)0``$P5%YB%A;_"OM2+X3NSO
MX#_N[^#_[9>'``"3AR<197&#N`<!`[B'`9!SE'>8>YQ_ROK.]M+R!N<BXQ>*
M```#.FH(`S,*`!K^`4,7(P``$P/CXA,)P0&^_)<G``"3AX?BJHD:\#[\%R,`
M`!,#H\J7)P``DX>GX<J%%R4``!,%!<H:]`+XQNC"[++PMO2Z^+[@@N3O\"^,
M$<6#1P4`*H1CE`<>IO[6[N_@O[,!)>_@7]YC#@44`&%C"P04(H7OX%^S!@4%
M!>_@W[,#1P0`JH2JBA7#VNH7*P``$PM+W":%VH9]5H5%[^#?VP-'%`")!`4$
M=?=6:X0(%R4``!,%I=`AH(ADH00-P<J%[_#/A"J$;=F#1P4`]=?O\*^.?=$B
MA>_@/\PJA!GM!!"`8`',@T<$`&.,!PPBA>_PKXQ=[8!DH01U]"*%[^#?JJJ$
M5H7OX%^JJ9R;A$1`)H7OX)^JUHB7)P``DX<GOA<H```3"*C3(H>7)@``DX:&
MTWU6A46JBN_@/]*3!0`<5H7OX)_#_5=C&/4`[^#_J!Q!14=CEN<,#`%6A>_@
M_\<JA!GERD>]9A%G]8]C@.<*EX<``(.WI_2#M@D`B&-6AQ<F```3!B;3A47O
MX!_+@41R=X,W"@"YCP%'8YT'+KI@&F3V:E9YMGD6>B:%]G1988*`(H7OX'^^
M*H2A!.,#!?(UOP%$);]B=208&<G*A>_@'_0!Q8-'!0"-XXADH01]]35%VNKO
MX'^=JH2JBA<D```3!.3#$P<P!5F][^`?NBJ$:=WOX)^:!@4%!96]VNIJ2^_@
MOYB;!P4`8P;[!%9KB;\7AP```S>GZ8.V"0`(8Q<F```3!D;$5H>%1>_@'\"!
MO^_P'\UR=X,W"@"YCP%'8Y@')"*%&F2Z8%9YMGD6>EEA;^"_L\I'WN;BXA,'
M`!R3]_<?8X;G`%9KMFL6;-6])H7OX+^3RH6JA!<E```3!27([^#_YZJ%8P\%
M$`.U"0#O\"_%JHMC"`407H7OX!^0&PL%`(U'8]AG`Q,%R_^7)0``DX5EQ5Z5
M[^!?H@GMD4=C!_L8FP>[_]Z7`\<'`),'\`)C#O<6RH47)0``$P5%I^_@'^)A
MQ8-'!0#IPQ,'``-CCN<*ER4``).%!:\7)0``$P4%I>_PCX#OX%^<*HB7*```
MDXCHSI<G``"3AV>=5H>7)@``DX9&P7U6A44FA>_@_[%]6<5)%RP``!,,;,R7
M*P``DXOKFA<K```3"^N_):#OX-^''$%CES<#[^`_EP4D*HABX**(WH=6A]J&
M?5:%12:%[^"_K9,%`!PFA>_@'Y_C""7]5H7OX'^;IH47)0``$P6%D^_@G_<F
MA>_PG[96:[9K%FSYNX.["0#%O8%%7H7OX-^O*HD=W>_P_Z"JB>-+!?*3!67_
M`49*A>_@/Y43"P$0&4;:A4J%[^!?HIE'8Q[U"`,G`1"W1T%#DX<',.,3]_`#
M5TL`D6>3AX=4XQSW[@%&DX7I_$J%[^!?D2`"$P:``J*%2H7OX'^>DP>``F,>
M]027*```DXBHO2*(ER<``).'!XQ6AY<F``"3AN:N?5:%12:%(P@!$N_@7Z`E
MOX.YB0#C@@GH3H7OX$_TC4?C_*?F<167)0``DX6%JDZ5[^#_AN,2!>;.B[F]
M%R4``!,%I:GO\!^0VNK>YN+B[^`?H:;^UN[:ZM[FXN+OX#^@.7$B^!>$```#
M-"2_2O!.[`;\)O12Z+,'1`"$8Y,)00`7B0```SGINH/'!`O.A1<E```3!06&
M`S<)`#KD`4>CB/0*[^`?PAG%`T<%`),'$`-C"_<2[_"OSK,'1`"$8R:%C48%
M1I<E``"3A:6E[^`O\*J$'<$<:3,'1``(8XQC%R8``!,&AJ3OX(_OG&B,8]Q%
M$Y>7`F-&!Q"S!T0`B&.-1@5&ER4``).%Q:+OX$_LJH07B@``$PIJO0W!SH47
M%0``$P6E=^_@_[DJAGG!G&@S!T0`"&.,8^_@C^JS!T0`A&,%1I<E``"3A46?
M)H7OX"_>JH47)@``$P;&GR:%[^`OZ!*4'&#.A1<5```3!05RHX@'"N_@'[4C
M.*H`*H0YQ9,%`!PBA>_@K_H;!Q4`A4=C\.<"Q4=C#?4`@S>*`*J&(H:,8Q<E
M```3!<6=[^!/_R)G@S<)`+F/`4>QZ^)P0G2B=`)YXFE":B%A@H`#-8H`[_!_
MFR,XJ@`JA%WQ%R4``!,%Q9?OX,_[@T<5`..*!^S9M0,WB@"<:`QCB&/OX#_H
M-;^S!T0`B&/OX(_V_;7OX#^%>7$B\";L!O07A````S1DH:J$3``7%0``$P6E
M;AQ@/N2!1^_@'ZD!S8-'!0")RQ,'``-CAN<`@<2#QP0`F>LB9QQ@N8\!1Z'O
MHG`"=.)D16&"@":%2NCO\&^CDP7P`BJ)[^#O\!G!$PD5`$J%[^`O[1%&EQ4`
M`).%Q7COX$_)&<%":76_(F<<8+F/`4>1ZP)T0FFB<":%XF1%86_@_[%*Z._@
M[_H3`0'4(SB!*B,\$2HC-)$J(S`A*R,\,2DC.$$I%X0```,TY)4T`,%N?5\<
M8",T\2B!1Y,(A0.3`H4'-H@37P\"MP__`)..#O`#M@@`00BA")-5!@(3%X8!
MDQ.&`)-7A@(37H8`DU2&`Q.3A0$S=^<!L_/S`;/WUP$S9W<`,W[>`<6/,W/C
M`:(%,V?'`1M6A@&SYV<`L_7U`5&/S8\C..C^(SSX_N.2$OO]5<9_9G\*9^)N
M`GXB<\)X8GB&8Y.$!B"!D1&@LH.P8IQBNH*A!K&/L\?W`;/'UP$3EQ<`_8-=
MCVV/N/[ZC_*.%H\:CD:#PH@>B..9EOR#/@4`HF\#.`4!`S.%`(,XA0$#/@4"
M-X>"6A,'EYF3U[X!$Y9>`%V.NI\37R,`DQ?C`6V.\I^S1A@!L^?G`;/V9@!^
MEL)O,_^W`+/&%@$VEK-&Z`%MCK/VU@&ZGY,25@"35+8!QI^SQ@8!_I:S[Y(`
M$]DN`).3[@'^EN)OL^,C`;/'=P#QC[J?[8ZSQ^<!PI^3E%8`$]FV`9,2Y@'^
MEPF"@G^SXL(`,^8D`;*7,\93`+J?L_.S`'6.[8]^GS-&=@"3E%<`$]FW`9.?
MY@%ZEHF"(G^S[]\`L^8D`3:6L\;R`6V.L_*R`/V..I\>GY,45@`36;8!L\96
M`).3YP&)@[/C\P#ZEK/G)`&^EC/_M@#"=K/'?P#QC[/_OP"ZEI:6DQ1?`!-9
MOP&SQ_<!MI>SYB0!MI>3$N8!"8*SXL(`,_:W`.)WL\93`+/VY@&S\[,`NI?^
MEY,45@`36;8!L\9V`+Z6L^<D`;Z6DQ_O`1-?+P"S[^\!,_^V`(9FL\?R`?&/
ML_*R`+J6GI:3%%\`$UF_`;/'5P"VE[/F)`&VEY,3Y@$)@K/CPP`S]K<`IF>S
MQG\`L_;F`;/_OP"ZEY:7DQ16`!-9M@&SQO8!OI:SYR0!OI:3$N\!$U\O`+/B
MX@$S_[8`QF:SQU,`\8^S\[,`NI;^EI,47P`36;\!L\=W`+:7L^8D`;:7DQ_F
M`0F"L^_/`#/VMP#F9[/&\@&S]N8!L_*R`+J7GI>3%%8`$UFV`;/&5@"^EK/G
M)`&^EI,3[P$37R\`L^/C`3/_M@"&=K/'?P#QC[/_OP"ZEI:6DQ1?`!-9OP&S
MQ_<!MI>SYB0!MI>3$N8!"8*SXL(`,_:W`*9WL\93`+/VY@&S\[,`NI?^EY,4
M5@`36;8!L\9V`+Z6L^<D`;Z6DQ_O`1-?+P"S[^\!,_^V`,9VL\?R`?&/L_*R
M`+J6GI:3%%\`$UF_`;/'5P"VE[/F)`&VEY,3Y@$)@K/CPP`S]K<`YG>SQG\`
ML_;F`;/_OP"ZEY:7DQ16`!-9M@&SQO8!OI:SYR0!OI:3$N\!$U\O`+/BX@$S
M_[8`BF:SQU,`\8^S\[,`NI;^EI,47P`36;\!L\=W`+:7L^8D`;:7DQ_F`0F"
ML^_/`#/VMP"J9[/&\@&S]N8!L_*R`+J7GI>35+8!DQ-6`+/&5@`3&>\!OI83
M7R\`L^>3`,IC,V_I`;Z6L\?O`>V.L_^_`+J3\8^>DI/4M@&SQ_<!DY-6`+/C
MDP"6E^IDDQ+F`0F"L^+"`)Z7[8\S1E\`NI0S?[\`$]FW`76.DY-7`*:?,T;F
M`;/C(P&S\[,`?I:3G^8!B8(>EK/OWP`*>;-TM@"SQO(!_8ZS\K(`DY-4`)/9
MM`$ZF3/'5@"SYC,!DY/G`8F#L^/S`$J?L\=_`.V.>I>QCRIV,P_7`#?WV6X3
M!Q>ZLWF_`!/9N0$ZEI.660`6ENV/L^8F`;*7[8Z^EI.2Y`'*=XF`L^*2`#/Y
MM@`SQE,`L_^_`)-4N0&ZES-/Y@$3%ED`,W^_`/Z718[ZEVV./I:3G^D!ZG>3
MV2D`L^\_`;-TM@`SS_(!L_.S`)/9M`&ZES-/WP"3EE0`,W^_`)Z7L^8V`?J7
M[8Z^EA,?Z0&.9Q-9*0`S;R\!L_.V`#/)[P&S^;(`NI>S0LD`$]FS`1.64P"S
M\K(`SI<S9B8!EI=MCCZ6DY+D`:YGB8"SXI(`,TE?`+-TM@"S^;\`NI>S3]D`
M$]FT`9.65`"S_[\`SI>SYB8!_I?MCKZ6DY_C`<YGD],C`+/O?P`SR?(!L_.V
M`+-YOP"ZES-/R0`3V;,!$Y93`#-_OP#.ES-F)@'ZEVV./I83G^0![F>)@#-O
MGP`SR>\!LW2V`+/YL@"ZE[-"V0`3V;0!DY94`+/RL@#.E[/F)@&6E^V.OI:3
MDN,!CG>3TR,`L^)R`#-)7P"S\[8`L_F_`+J7LT_)`!/9LP$3EE,`L_^_`,Z7
M,V8F`?Z7;8X^EI.?Y`&N=XF`L^^?`#/)\@&S=+8`LWF_`+J7,T_9`!/9M`&3
MEE0`,W^_`,Z7L^8F`?J7[8Z^EA.?XP'.=Y/3(P`S;W\`,\GO`;/SM@"S^;(`
MNI>S0LD`$]FS`1.64P"S\K(`SI<S9B8!EI=MCCZ6DY+D`>YWB8"SXI(`,TE?
M`+-TM@"S^;\`NI>S3]D`$]FT`9.65`"S_[\`SI>SYB8!_I?MCKZ6DY_C`9)G
MD],C`+/O?P`SR?(!L_.V`+-YOP"ZES-/R0`3V;,!$Y93`#-_OP#.ES-F)@'Z
MEVV./I83G^0!LF>)@#-OGP`SR>\!LW2V`+/YL@"ZE[-"V0`3V;0!DY94`+/R
ML@#.E[/F)@&6E^V.OI:3DN,!TF>3TR,`L^)R`#-)7P"S\[8`L_F_`+J7LT_)
M`!/9LP$3EE,`L_^_`,Z7,V8F`?Z7;8X^EI.?Y`'R9XF`L^^?`#/)\@&S=+8`
MLWF_`+J7,T_9`!/9M`&3EE0`,W^_`,Z7L^8F`?J7[8Z^EA.?XP&2=Y/3(P`S
M;W\`,\GO`;/SM@"S^;(`NI>S0LD`$]FS`1.64P"S\K(`SI<S9B8!EI=MCCZ6
MDY+D`;)WB8"SXI(`,TE?`+-TM@"S^;\`NI>S3]D`$]FT`9.65`"S_[\`SI>S
MYB8!_I?MCKZ6DY_C`=)WD],C`+/O?P`S^;8`L\/R`;-YOP"ZES//PP"34[D!
M$Q99`#-_OP#.ES-F=@!MCOJ7,X_'`).3Y`'R=XF`L^.3`#/&?P"S=+\`L_*R
M`+J7L8[MCI/9M`&6EY.25`"VE[/F,@&VEQ,6Z0&69A-9*0`S9B8!,\G#`+/R
MMP"S_[\`LT?I`;J6D]FR`?Z6$YE2`+/_MP`S:3D!_I;*EA.?Y`&)@#-OGP`W
M]\8CLW2V`/U7]8VV9H&3"@<3!\?-LW__`#-FY@$S^?0!NI8S=E8`L_/S`+:3
MD]FU`3-F)@$3F54`'I:S8SD!'I:S<_8`DY;B`59FD](B`+/F5@"S\O8`,V_?
M`#/Y7P`ZEC-_OP"RE)/9LP$S;R\!$YE3`":?LV0Y`1.6Y0$FGXF!]F1-CK-U
M]@#1CC-__P`S^;(`L_9V`+J4_I236;\!L^8F`1,97P"FEK-D.0$3FN,!D]\C
M`*:6EG2S;_H!L_/_`#-F]@']CC/Y=0"ZE#-VY@&FDC-F)@&3E%8`$]FV`;/D
M)`$6EI,9[P$FEA-?+P"V=#/OZ0&S<O\`L^_O`7V.,_E3`+/_WP"ZE+/O+P&N
ME!,95@"36;8!DY7F`8F"U8VSAI\`LV\Y`?Z6UG^S]/4`,V^_`/V.,_F2`+J?
M,W_/`#-O+P'^DQ.95@"3V;8!DQ_F`0F"L^_/`#,&?P`S;SD!>I9V?[/S_P"S
MY?4!?8XS^70`.I_UC;/E)0'ZDA,95@"36;8!$Y_F`8F",V_?`+.&50"S93D!
MKI::9;-R_P"S[^\!_8XS^5,`NI6S_\\`L^\O`:Z4$YE6`)/9M@&3%>8!"8+1
MC3.&GP"S;SD!?I:Z;[/T]0`S;[\`?8XS^9(`NI\S?]\`,V\O`?Z3$QE6`)-9
MM@&3G^8!B8*S[]\`LP9_`#-O.0'ZEEIOL_/_`+/E]0']CC/Y=``ZG_&-L^4E
M`?J2$YE6`)/9M@$3'^8!"8(S;\\`,X95`+-E.0$NEOIELW+_`+/O[P%]CC/Y
M4P"ZE;/_WP"S[R\!KI03&58`DUFV`9.5Y@&)@M6-LX:?`+-O.0'^EII_L_3U
M`#-OOP#]CC/YD@"ZGS-_SP`S;R\!_I,3F58`D]FV`9,?Y@$)@K/OSP`S!G\`
M,V\Y`7J6.G^S\_\`L^7U`7V.,_ET`#J?]8VSY24!^I(3&58`DUFV`1.?Y@&)
M@C-OWP"SAE4`LV4Y`:Z6VG6S<O\`L^_O`?V.,_E3`+J5L__/`+/O+P&NE!.9
M5@"3V;8!DQ7F`0F"T8TSAI\`LV0Y`2:6^G2S__4`,V^_`'V.,_GR`3-_WP"Z
ME#-O+P&>E!,95@"36;8!DY/F`8F"L^/3`+,&GP"S9#D!'FDS__,`L^5U`*:6
M\8VS].\!.IG]CA:9Q8V3F58`$]JV`9-2)@"3%.8!RI4^:;/D5``SYDD!L_+T
M`+*5,^:3`'6.L_/U`#J9LW5?`'Z9DYE3`!/:LP%-CI/?)@"3E>8!2I:SYDD!
ML^7U`3:6L^:T`+-T]@!>9K/_]0`S^?(!L_9V`#J6>I:SYB8!$Y]4`!/9M`$S
M;R\!LI9^:1.6XP&3TR,`,V9V`+-S]@#ZEM&-_8XS^G\`Y8TZF1.?5@"3V;8!
M%IFSY44!LV(_`<J5$]\D`!.9Y`&S9.D!'G^S\O(`EI5%CK/R]``S^?4`,_I3
M`'6..I^36;D!$Q=9`'Z?,V9&`;-O-P%ZEI.9Y@$3WR8`,^_I`;/&Y`&S__\`
MK8XWMY@ROG6RGPH'$P=G';/Y_P"3U+D!NI43EED`GI7]CD6.DQ/I`1-9*0"S
MXR,!?8ZNEK.%Q@`S1G\`,T;V`=Y_L_3U`!/9M`&ZGY.65`"6GWV.L^8F`?V.
M?I8VEI.?Z0'^=I/9*0"S[S\!,WGV`+/"\P&S>?\`NI8SS[(`DU*Y`9,560`S
M?_\`SI:SY54`^I;]C;:5$Y_D`8,V`2")@#-OGP"SPN\!L_3U`+/S\P"3V;0!
MNI:SPL(`$Y94`+/R\@">EC-F-@&6EGV.-I:3$ND!@S:!(!-9*0"SXB(!LW/V
M`#-)7P"S^?\`NI:S3[D`$]FS`9.54P"S__\`SI:SY24!_I;]C;:5DY_D`8,V
M`2&)@+/OGP`SR?(!L_3U`+-Y_P"ZEC-/R0`3V;0!$Y94`#-__P#.EC-F)@'Z
MEGV.-I83G^,!@S:!(9/3(P`S;W\`,\GO`;-S]@"S^?(`NI:S0KD`$]FS`9.5
M4P"S\O(`SI:SY24!EI;]C;:5DY+D`8,V`2*)@+/BD@`S25\`L_3U`+/Y_P"Z
MEK-/R0`3V;0!$Y94`+/__P#.EC-F)@'^EGV.-I:3G^,!@S:!(I/3(P"S[W\`
M,\GR`;-S]@"S>?\`NI8S3[D`$]FS`9.54P`S?_\`SI:SY24!^I;]C;:5$Y_D
M`8,V`2.)@#-OGP`SR>\!L_3U`+/Y\@"ZEK-"R0`3V;0!$Y94`+/R\@#.EC-F
M)@&6EGV.-I:3DN,!@S:!(Y/3(P"SXG(`,TE?`+-S]@"S^?\`NI:S3[D`$]FS
M`9.54P"S__\`SI:SY24!_I;]C;:5DY_D`8,V`22)@+/OGP`SR?(!L_3U`+-Y
M_P"ZEC-/R0`3V;0!$Y94`#-__P#.EC-F)@'ZEGV.-I83G^,!@S:!))/3(P`S
M;W\`,\GO`;-S]@"S^?(`NI:S0KD`$]FS`9.54P"S\O(`SI:SY24!EI;]C;:5
MDY+D`8,V`26)@+/BD@`S25\`L_3U`+/Y_P"ZEK-/R0`3V;0!$Y94`+/__P#.
MEC-F)@'^EGV.-I:3G^,!@S:!)9/3(P"S[W\`,\GR`;-S]@"S>?\`NI8S3[D`
M$]FS`9.54P`S?_\`SI:SY24!^I;]C;:5$Y_D`8,V`2:)@#-OGP`S^?4`L\3O
M`;/Y\@"ZEK/"Q`"35+D!$Q99`+/R\@#.ED6.EI9]CC:6DY3C`8,V@2:3TR,`
ML^1T`+-"GP"S<_8`L_G_`+J6L\^R`)/2LP&3E5,`L___`,Z6L^55`/V-_I:S
MC[8`DQ+I`8,V`2<362D`L^(B`;/%5``S^?\`,W__`)-9N0&ZEK&-$Q99`/V-
M^I8S9C8!?8ZNEK.%Q@`3G^,!`S:!)Y/3(P`S;W\`L\;B`;/S]0#]C#J6L\;V
M`?V.)I:3V;,!DY13`#:6L^8T`3:6@S8!*),?Z0$362D`L^\O`;J6LT3_`3-W
M]@#VEK/R\@`SQK0`?8Z3%5<`DUZW`9:6LI8SYM4!DY7C`9/3(P"REK/E=0#]
MCCJ3,P;/`3.'!0&SA1\!?8\4X?V-LW;S`/&/&.D<\13E#.T#-X$H'&"YCP%'
MA>.#,($K`S0!*X,T@2H#.0$J@SF!*0,Z`2D3`0$L@H#OT$_401$3!0`(!N3O
MT(^DMW9=3#=WZ6&W)45GDX45,(8&-U8R$`8'#.&3AN;/ET4``(.U94,3!F9'
M$P<''PSE%.D0[1CQ(S0%`B,X!0(C+`4&HF!!`8*`.7$B^";T2O!6Y`;\3NQ2
MZ!AUDQ<V`!1YNI>"%X&3,[?G`*J$NI8H71-7U@$VEYSTF/@RB2Z$DXJ$`S'M
MDP?P`V/<)PD;"0G\&UII`)L)&@":":*9HH43!@`$5H7OT`^K$P0$!":%[^#?
MS>,5-/\;&FH`.PE)04J&SH56A>_0#ZDCK"0'XG!"=*)T`GGB:4)JHFHA88*`
MDPD`!+N'J4"^B6-*]@(;B@D`DXJ$`U*&HH56E>_0KZ6\7!,'``2[AOD`M-SC
MD>;\)H4["3E!4I3OX%_'K;>RB?FWHHEQOWEQ(O`F[%+@!O1*Z$[D@[F%`A.*
MA0.3!@#X$]8Y`!-V]@,S!\H``[D%`Y,'%@`C`-<`$P>``RZ$JH0%)F-7]Q(3
M!P`$$9^11C,%^@!C==<4B4=C>?<28Q0'$B*%[^"_P!,&@`.!15*%[]"/L9-6
M"0$35XD`D_;V#Z(&FU>)`1-W]P]"!]6/$WGY#V()V8\;UHD!D]8)`0(6L^<G
M`1/7B0"3]O8/HA;1CQ-W]P]"%]6/XAG9C[/G-P$\^"*%[^"_NAQ@(H7A@R.`
M]``<8,&#HX#T`!Q@H8,C@?0`'&"C@?0`'&3A@R."]``<9,&#HX+T`!QDH8,C
M@_0`'&2C@_0`'&CA@R.$]``<:,&#HX3T`!QHH8,CA?0`'&BCA?0`'&SA@R.&
M]``<;,&#HX;T`!QLH8,CA_0`'&RCA_0`''#A@R.(]``<<,&#HXCT`!QPH8,C
MB?0`''"CB?0``G2B<.)D0FFB:0)J16%OT*^4$P>``SL&QT"!13,%^@#OT(^@
MQ;TC``4`X;TC``4`HP`%`'D7"07C!0?L[;<C``4`HP`%`",!!0"C`04`<1>)
M1Q$%XV7WZM&_EV8``(.VYDAOT&^!```!``(``````"5S+R5S````+W!R;V,O
M<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``````26YT
M97)N86QS.CI005(Z.D)/3U0`````97AE```````O<')O8R\E:2\E<P``````
M+@````````!005)?5$5-4```````````4$%27U!23T=.04U%`````#H`````
M````+P`````````E<R5S)7,``%!%4DPU3$E"``````````!015),3$E"`%!%
M4DPU3U!4``````````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1```````4$%27T-,14%.`````````%!!4E]$14)51P````````!005)?
M0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``````````4$%27T=,3T)!
M3%]435!$25(`````````4$%27U1-4$1)4@```````%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.```````````Q`````````&QS965K(&9A:6QE
M9`````!R96%D(&9A:6QE9```````3$1?3$E"4D%265]0051(`%-94U1%30``
M+W1M<`````!54T52`````%5315).04U%```````````E,#)X`````'!A<BT`
M````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P
M87)L`````"YP87(`````<VAO<G0@<F5A9````````"5S)7-C86-H92TE<R5S
M```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````&```
M``````!P97)L`````#``````````4$%2.CI086-K97(Z.E9%4E-)3TX`````
M,2XP-C,```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````+64````````M+0``````
M`%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I
M>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%
M7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S
M:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@
M9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ
M92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY
M("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@
M("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D
M("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD[
M"FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I
M('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]
M"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\
M/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL
M96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64[
M"FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES
M=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<
M)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO
M=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*
M;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)
M0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO
M<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@
M<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A
M(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G
M:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG
M("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'
M24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I
M8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D
M8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U
M;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U
M9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE
M.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E
M="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`[
M"B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I
M<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II
M<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968[
M"B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S
M(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H
M;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD
M?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF
M("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D
M<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S
M(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@
M)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M
M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*
M<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E
M9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N
M86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A
M<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII
M9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C
M:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ
M6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M
M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=
M*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R
M86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!
M4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@
M/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I
M8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I
M"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H
M95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C
M86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I
M('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@
M,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P
M96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O
M;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D
M96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE
M=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@!P97)L>'-I+F,``````````$-!0TA%``")J\WO``````$;
M`SOD````&P```/B0__\X!@``A)+___P````\D___$`$``.B3__]\`0``0I3_
M_Z@!``!(E?__``(``/:6__]@`@``W)?__Z`"```VF/__Q`(``%Z8___8`@``
M')G__Q`#```>F?__)`,``/2:__]X`P``%IO__Y@#```8G/__W`,``'"?__\0
M!```OI___S0$```"H/__3`0``":A__^<!```/J'__[@$``#^H?__#`4``-JF
M__^X!0``BJC___`%```NJ?__<`8``)B[__^H!@``[+O__\@&``#(O/__``<`
M```````0``````````-Z4@`!?`$!&PT"`!`````8````@)'__R(`````!P$`
M:````"P````DDO__K`````!"#D!$@0*(!$R6$%*2"),*E`QFB0:5#F;)0M)"
MTT+40M5"UD+!1,A"#@!"#D"!`H@$B0:2"),*E`R5#I804,G2T]35UD26$$+6
M1)((DPJ4#)801M)"TT+40M8`*````)@```!DDO__6@````!"#K`!1H@$B0:!
M`@)&"L%"R$+)0@X`0@L```!4````Q````)*2__\&`0```$(.P`%$DPJ!`EB(
M!$;(4,%"TT(.`$(.P`&!`H@$DPI$B0:2"'*4#`)6U%0*R$+)0M)""U*4#$C(
MR=+42(@$B0:2")0,````7````!P!``!`D___K@$```!"#F!4B`2)!I((E`R!
M`I,*E0Z6$`+0"L%"R$+)0M)"TT+40M5"UD(.`$(+;I<2F!0"5@K70MA$"U37
MV$27$I@41M?81)<2F!1&UT+8````/````'P!``".E/__Y@````!"#E!$E0Y:
M#M`@B`2)!I((DPJ4#($"`GH*#E!"P4+(0LE"TD+30M1"U4(.`$(+`"````"\
M`0``-)7__UH`````0@X00H@$2H$":,A"P5X.`````!````#@`0``:I7__R@`
M````````-````/0!``!^E?__O@````!"#E!$B090#M!`@0*(!)((DPH"E`H.
M4$+!1,A"R4+20M-"#@!""P`0````+`(```26__\"`````````%````!``@``
M\I7__]8!````1@[P`68.\"&(!(D&D@B8%($"DPJ4#)4.EA"7$ID6FA@"8@H.
M\`%"P4+(0LE"TD+30M1"U4+60M="V$+90MI"#@!""QP```"4`@``=)?__R(`
M````0@X02(@$@0)0R$+!0@X`0````+0"``!VE___`@$```!"#C!2#K`@D@B!
M`H@$B08"J`H.,$+!0LA"R4+20@X`0@M6"@XP0L%"R$+)0M)*#@!$"P`P````
M^`(``#28__]8`P```$(.0$J(!(D&D@B3"H$"`PH#"LA"P4+)0M)"TU(.`$0+
M````(````"P#``!8F___3@````!"#B!$B`2!`GH*P4+(0@X`0@L`%````%`#
M``""F___1`````!"#F!"@1(`3````&@#``"NF___)`$```!"#G!$B`1<#O"`
M!),*E`R9%H$"B0:2")4.EA"7$I@4`L(*#G!"P4+(0LE"TD+30M1"U4+60M="
MV$+90@X`0@L8````N`,``(*<__\8`````$(.$$*!`E#!0@X`4````-0#``!^
MG/__P`````!"#D!&B0:2"($":(@$1LA8P4+)0M)"#@!$#D"!`H@$B0:2"$23
M"@)"R$+30L%"R4+22@X`1`Y`@0*)!I((1(@$DPH`J````"@$``#JG/__W`0`
M``!*#I`#6I((DPJ4#($"B`0";(D&E0YNEA!@U@/R``K!0LA"U4+20M-"U$3)
M0@X`0@MR"I805@M4EA!0UF+)U5;(0L%"TD+30M1"#@!$#I`#@0*(!(D&D@B3
M"I0,E0Z6$$Z7$I@41M9"UT+80I80EQ*8%`,P`0K60M="V$(+`^``UM?81I80
MEQ*8%$3)U=;7V$J)!I4.EA"7$I@4`#0```#4!```&J'__[`!````0@Y`0H@$
M4I((DPJ!`HD&E`P#1@$*P4+(0LE"TD+30M1"#@!""P``1`````P%``"2HO__
MI`````!"#C!&B`2)!H$"`D(*P4+(0LE"#@!""T22"&P*TD(+3,A"TD+!1,E"
M#@!$#C"!`H@$B09"D@@`-````%0%``"XBO__B@$```!"#F!,@0*)!H@$D@B3
M"@,.`0K!0LA"R4+31-)"#@!""P`````````T````C`4``+:B__]J$@```$0.
MP`58B`2!`HD&D@B3"I0,`S`2"L%$R$3)1-)$TT341`X`0@L``!P```#$!0``
MZ+3__U0`````0@X01H$"`DC!0@X`````-````.0%```<M?__W`````!"#D!.
MB`2)!I((E0Z!`I,*E`P"=@K!0LA"R4+20M-"U$+50@X`0@LT````'`8``,"U
M__^R`0```$(.,$R(!(D&E`R!`I((DPH#3`$*R$+!0LE"TD+30M1"#@!$"P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````0``````
M``#F`@````````$`````````]@(````````!```````````#````````(```
M``````"@JP```````"$`````````"``````````9`````````*BK````````
M&P`````````(`````````!H`````````L*L````````<``````````@`````
M````]?[_;P````#8`@````````4`````````*`T````````&`````````,@#
M````````"@````````"J!`````````L`````````&``````````5````````
M`````````````P````````#(K0````````(`````````0`4````````4````
M``````<`````````%P`````````0%0````````<``````````!,````````(
M`````````%`'````````"0`````````8`````````!X`````````"```````
M``#[__]O``````$```@`````_O__;P````"@$@```````/___V\``````@``
M``````#P__]O`````-(1````````^?__;P`````+````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````__________\``````````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````4!H```````!0&@```````%`:````````4!H```````!0&@``
M`````%`:````````4!H```````!0&@```````%`:````````4!H```````!0
M&@```````%`:````````4!H```````!0&@```````%`:````````4!H`````
M``!0&@```````%`:````````4!H```````!0&@```````%`:````````4!H`
M``````!0&@```````%`:````````4!H```````!0&@```````%`:````````
M4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````4!H```````!0&@```````%`:````````4!H```````"XJP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H1&5B:6%N(#$S+C(N,"TQ."D@,3,N,BXP`$%2````<FES8W8``4@`
M```$$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?>FEC<W(R
M<#!?>FEF96YC96DR<#!?>FUM=6PQ<#```"YS:'-T<G1A8@`N:6YT97)P`"YN
M;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA
M+F1Y;@`N<F5L82YP;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE
M:%]F<F%M90`N<')E:6YI=%]A<G)A>0`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A
M>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+G)I<V-V+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M````````<`(```````!P`@```````"$````````````````````!````````
M````````````$P````<````"`````````)0"````````E`(````````D````
M````````````````!````````````````````"8````'`````@````````"X
M`@```````+@"````````(`````````````````````0`````````````````
M```T````]O__;P(`````````V`(```````#8`@```````.P`````````!0``
M```````(````````````````````/@````L````"`````````,@#````````
MR`,```````!@"0````````8````"````"``````````8`````````$8````#
M`````@`````````H#0```````"@-````````J@0```````````````````$`
M``````````````````!.````____;P(`````````TA$```````#2$0``````
M`,@`````````!0`````````"``````````(`````````6P```/[__V\"````
M`````*`2````````H!(```````!@``````````8````"````"```````````
M`````````&H````$`````@``````````$P`````````3````````$`(`````
M```%``````````@`````````&`````````!T````!````$(`````````$!4`
M```````0%0```````$`%````````!0```!0````(`````````!@`````````
M>0````$````&`````````%`:````````4!H```````"@`P``````````````
M````$``````````0`````````'X````!````!@````````#P'0```````/`=
M````````CBT```````````````````0```````````````````"$`````0``
M``(`````````@$L```````"`2P```````'A!```````````````````(````
M````````````````C`````$````"`````````/B,````````^(P```````#D
M````````````````````!````````````````````)H````!`````@``````
M``#@C0```````."-````````5`8```````````````````@`````````````
M``````"D````$`````,`````````H*L```````"@FP````````@`````````
M```````````!``````````@`````````LP````X````#`````````*BK````
M````J)L````````(````````````````````"``````````(`````````+\`
M```/`````P````````"PJP```````+";````````"```````````````````
M``@`````````"`````````#+````!@````,`````````N*L```````"XFP``
M`````!`"````````!@`````````(`````````!``````````U`````$````#
M`````````,BM````````R)T````````X`@``````````````````"```````
M```(`````````-D````!`````P``````````L`````````"@````````4```
M``````````````````@```````````````````#?````"`````,`````````
M4+````````!0H````````"@````````````````````(````````````````
M````Y`````$````P````````````````````4*`````````?````````````
M`````````0`````````!`````````.T````#``!P````````````````````
M`&^@````````4P````````````````````$````````````````````!````
M`P````````````````````````#"H````````/\````````````````````!
/````````````````````
